@@ -9,6 +9,7 @@ use eva_common::events::{
 use eva_common::prelude::*;
 use eva_common::services;
 use eva_common::SLEEP_STEP;
+pub use eva_sdk_derive::svc_main;
 use lazy_static::lazy_static;
 use log::{Level, Log};
 use serde::Deserialize;
@@ -22,7 +23,6 @@ use std::time::{Duration, Instant};
 use tokio::io::AsyncReadExt;
 use tokio::signal::unix::{signal, SignalKind};
 use tokio::time::sleep;
-pub use eva_sdk_derive::svc_main;
 
 #[derive(Debug, Copy, Clone, Eq, PartialEq)]
 pub enum EventKind {
@@ -349,7 +349,7 @@ pub fn svc_start_signal_handlers() {
 }
 
 fn process_initial(buf: &[u8]) -> EResult<services::Initial> {
-    let initial: services::Initial = rmp_serde::from_read_ref(buf)?;
+    let initial: services::Initial = rmp_serde::from_slice(buf)?;
     if initial.config_version() != services::SERVICE_CONFIG_VERSION {
         return Err(Error::not_implemented(format!(
             "config version not supported: {}",
